# About RF Protocols wit 433 MHz

These are some comments from my experience and observations when using 433 MHz OOK / ASK transmitter and receivers and protocols.

Actually 433.92MHz (almost 434MHz) is used.

The simple devices using 433MHz signals use on/off patterns (OOK/ASK) to send a specific information over the air.
Most protocols define code patterns for start and stop, LOW bits and HIGH bits but there are also protocols that use more than 2 code patterns.


## Signal decoding

The implementation of the library is made up of 3 parts:

* The SignalCollector uses an interrupt routine and produces a stream of numbers that correlate to the time between 2 signal changes.
The timings are delivered to a static ring buffer so the interrupt routine can return as soon as possible.
By calling the loop() function in the loop() function of the main sketch the signal timings are taken from the buffer and are passed to the SignalParser. 

* The SignalParser checks in every defined protocol wether the given durations match.
This happens independently on every protocol. To safe computing time, only required protocols should be loaded.

* When a complete protocol is found a callback function is called with the textual representation of the protocol.
This may be by detecting a stop code or reaching the maximum length of the protocol.
Decoding the transferred vales is implemented on he base of this value. 

* When receiving a timing that doesn't fit to any defined code the receiving is reset and will restart with a next starting code that is detected.


## Analyzing new codes

Analyzing new codes is an it adventure in itself. The following steps have been useful for me:

* Collect some timings using the `scanner.ino` example. This sketch collects many durations using the same method like the SignalParser and writes them to the Serial output.

* Search the internet and the referenced sources for the protocol and device for any hints you can get.
 
* Create a new protocol definition. Examples can be found in `protocols.h`.

* Use the `testcodes.ino` example with the given durations and optonally enable the TRACE_MSG and INFO_MSG outputs i the SignalParser to see how the codes are parsed.


## Finding Codes and hints on the internet

There are some good sources of protocol definitions available. Here are some links I found useful:

* <https://manual.pilight.org/protocols/433.92/index.html>
* <https://github.com/pilight/pilight/tree/master/libs/pilight/protocols/433.92>
* <https://github.com/sui77/rc-switch/blob/master/RCSwitch.cpp>
* <https://goughlui.com/2016/05/01/shootout-four-433-92mhz-askook-transmitter-modules-compared/>
* <https://github.com/ninjablocks/433Utils>
* <http://fedmow349.blogspot.com/2013/05/hacking-433mhz-rf-link-home-automation.html>
* <https://tinkerman.cat/post/decoding-433mhz-rf-data-from-wireless-switches-the-data>
* <https://alexbloggt.com/funksteckdosensteuerung-mit-esp8266/>
* <https://forum.arduino.cc/index.php?topic=368465.0>



## Why RF signals sometime fail...

### 1. Some noise from somewhere else

Here is an example next to a `[it2 s_##___#____#_#__###_____#____#__x]` sequence.
When receiving the 15. code the pause expected to have 1250 µsecs. was interrupted by another signal and ended therefore with about 409 µsecs.

```TXT
s 283	2658
_ 286  255 296 1269 	
# 286	1269 287  267 	
# 285	1268 289  264 	
_ 285	 249 289 1278 	
_ 286	 251 285 1282 	
_ 289	 249 287 1278 	
# 288	1268 291  261 	
_ 294	 239 294 1287 	
_ 287	 252 286 1281 	
_ 284	 254 287 1278 	
_ 290  251 286 1279 	
# 285	1259 294  268 	
_ 283	 259 287 1272 	
  291  409
```

This kind of disruption is stopping code recognition or will result in random codes received.
Better no code than any false code.

Especially in start/stop codes often a long pause is used that is sensitive for noise from somewhere else.


### 2. Automatic receiver signal amplification

Under real conditions senders may be far away producing low signals or may be nearby producing high signals. 
Therefore many receivers have an automatic level adjustment for the sensitivity of the input.

This results often in receiving much short pulse noise when no signal is actually sent because the receiving amplifier volumes gets higher and higher until any signal is found. When then a nearby sender is activated, the amplification is too high for some milliseconds until the automatic level is reduced to a usable amount.

This results in missing the first timings of a sequence correctly.

Repeating the same signal in the sender for multiple times or sending a extra start signal is a approbate method to level all receivers to the right level.


### 3. Low signals

Use a good antenna with the right length. (17.3 cm)

You can also find small helicals. They are not as good as a 1/4 wave length antennas but save space.

You can find cheap antennas and outdoor antennas at eBay...


## TODO

* Add more protocols
* Port back to AVR.
* Use debugging output not using printf to save memory on AVR cores.
* Documentation on <https://www.mathertel.de/Arduino/TabRF.aspx>


